==> lambda-event-sources-1.60.0-sources.jar: software/amazon/awscdk/services/lambda/eventsources/StreamEventSource.java <==
package software.amazon.awscdk.services.lambda.eventsources;

/**
 * Use an stream as an event source for AWS Lambda.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:27.894Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.eventsources.$Module.class, fqn = "@aws-cdk/aws-lambda-event-sources.StreamEventSource")
public abstract class StreamEventSource extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.lambda.IEventSource {

    protected StreamEventSource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StreamEventSource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected StreamEventSource(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.eventsources.StreamEventSourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Called by `lambda.addEventSource` to allow the event source to bind to this function.
     * <p>
     * @param _target This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public abstract void bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction _target);

    /**
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.EventSourceMappingOptions enrichMappingOptions(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.EventSourceMappingOptions options) {
        return this.jsiiCall("enrichMappingOptions", software.amazon.awscdk.services.lambda.EventSourceMappingOptions.class, new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.eventsources.StreamEventSourceProps getProps() {
        return this.jsiiGet("props", software.amazon.awscdk.services.lambda.eventsources.StreamEventSourceProps.class);
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.services.lambda.eventsources.StreamEventSource {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Called by `lambda.addEventSource` to allow the event source to bind to this function.
         * <p>
         * @param target That lambda function to bind to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public void bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction target) {
            this.jsiiCall("bind", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(target, "target is required") });
        }
    }
}

==> lambda-event-sources-1.118.0-sources.jar: software/amazon/awscdk/services/lambda/eventsources/StreamEventSource.java <==
package software.amazon.awscdk.services.lambda.eventsources;

/**
 * Use an stream as an event source for AWS Lambda.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-08-11T00:50:33.866Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.eventsources.$Module.class, fqn = "@aws-cdk/aws-lambda-event-sources.StreamEventSource")
public abstract class StreamEventSource extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.lambda.IEventSource {

    protected StreamEventSource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StreamEventSource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected StreamEventSource(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.eventsources.StreamEventSourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Called by `lambda.addEventSource` to allow the event source to bind to this function.
     * <p>
     * @param _target This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public abstract void bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction _target);

    /**
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.EventSourceMappingOptions enrichMappingOptions(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.EventSourceMappingOptions options) {
        return software.amazon.jsii.Kernel.call(this, "enrichMappingOptions", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.EventSourceMappingOptions.class), new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.eventsources.StreamEventSourceProps getProps() {
        return software.amazon.jsii.Kernel.get(this, "props", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.eventsources.StreamEventSourceProps.class));
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.lambda.eventsources.StreamEventSource implements software.amazon.awscdk.services.lambda.IEventSource.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Called by `lambda.addEventSource` to allow the event source to bind to this function.
         * <p>
         * @param _target This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final void bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction _target) {
            software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(_target, "_target is required") });
        }
    }
}
